@@ -3,7 +3,6 @@ import sys
 import time
 import signal
 import logging
-import importlib
 import subprocess
 from typing import List, Union
 from multiprocessing import cpu_count
@@ -54,7 +53,7 @@ def main(env, debug):
     config.import_from_environ()
     Index().rebuild_app()
     # set index logger level
-    logging.getLogger("index").setLevel(LOG_LEVELS[config.log_level])
+    logging.getLogger("indexpy").setLevel(LOG_LEVELS[config.log_level])
 
 
 @main.command(help="use only uvicorn to deploy")
