@@ -140,8 +140,10 @@ class Config(UpperDict, metaclass=Singleton):
         self["host"] = "127.0.0.1"
         self["port"] = 4190
         self["log_level"] = "info"
-        self["hotreload"] = True
-        self["autoreload"] = False
+        self["hotreload"] = False
+        self["autoreload"] = True
+        # template
+        self["templates"] = ("templates",)
         # url
         self["allow_underline"] = False
         # middleware
