@@ -2,6 +2,7 @@
 Load some preset functions into Index
 """
 import os
+import logging
 from typing import Optional
 
 from starlette.staticfiles import StaticFiles
@@ -10,6 +11,8 @@ from .config import here
 from .autoreload import MonitorFile
 from .applications import Index
 
+logging.getLogger("multipart").setLevel(logging.INFO)
+
 app = Index()
 
 app.mount(
@@ -22,31 +25,30 @@ app.mount(
 monitor: Optional[MonitorFile] = None
 
 
-@app.on_event("startup")
+@app.on_startup
 def check_on_startup() -> None:
     # monitor file event
     global monitor
     monitor = MonitorFile(here)
 
 
-@app.on_event("shutdown")
+@app.on_shutdown
 def clear_check_on_shutdown() -> None:
     global monitor
     if monitor is not None:
         monitor.stop()
 
 
-@app.on_event("startup")
+@app.on_startup
 def create_directories() -> None:
     """
     create directories for static & template
     """
     os.makedirs(os.path.join(here, "views"), exist_ok=True)
     os.makedirs(os.path.join(here, "static"), exist_ok=True)
-    os.makedirs(os.path.join(here, "templates"), exist_ok=True)
 
 
-@app.on_event("shutdown")
+@app.on_shutdown
 def clear_directories() -> None:
     """
     if no files exist in the directory, delete them
@@ -60,4 +62,3 @@ def clear_directories() -> None:
 
     rmdir(os.path.join(here, "views"))
     rmdir(os.path.join(here, "static"))
-    rmdir(os.path.join(here, "templates"))
